/*
 * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef __XMLNAMESPACE_H__
#define __XMLNAMESPACE_H__

#include <string>

class XMLNamespace {

private:
	XMLNamespace();

public:
	static const std::string DublinCorePrefix;
	static const std::string DublinCoreLegacyPrefix;
	static const std::string DublinCoreTerms;
	static const std::string XLink;
	static const std::string OpenPackagingFormat;
	static const std::string Atom;
	static const std::string OpenSearch;
	static const std::string CalibreMetadata;
	static const std::string Opds;
};

#endif /* __XMLNAMESPACE_H__ */
